@@ -7,6 +7,7 @@ Let's make that as easy as possible.
 from _version import __version__
 
 import contextlib
+import email
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 import smtplib
@@ -15,18 +16,22 @@ import types
 import ffs
 from ffs.contrib import mold
 import jinja2
-import regex
 
 __all__ = [
     '__version__',
     'Postman',
     'DjangoPostman',
     'GmailPostman',
+    'setup_test_environment',
+    'teardown_test_environment'
     ]
 
 u = unicode
 flatten = lambda x: [item for sublist in x for item in sublist]
 
+OUTBOX = []
+SMTP   = None
+
 class Error(Exception): pass
 class NoTemplateError(Error): pass
 class NoContentError(Error): pass
@@ -72,6 +77,7 @@ class BaseMailer(object):
         if not plain and not html:
             raise NoContentError()
 
+
 class BaseSMTPMailer(BaseMailer):
     """
     Construct the message
@@ -113,6 +119,7 @@ class BaseSMTPMailer(BaseMailer):
 
         self.deliver(msg)
 
+
 class SMTPMailer(BaseSMTPMailer):
     """
     Use SMTP to deliver our message.
@@ -143,6 +150,7 @@ class SMTPMailer(BaseSMTPMailer):
         s.quit()
         return
 
+
 class SMTPAuthenticatedMailer(BaseSMTPMailer):
     """
     Use authenticated SMTP to deliver our message
@@ -176,7 +184,6 @@ class SMTPAuthenticatedMailer(BaseSMTPMailer):
         return
 
 
-
 class DjangoMailer(BaseMailer):
     """
     Send email using whatever is configured in our Django project's
@@ -367,7 +374,6 @@ class SMTPAuthenticatedPostman(BasePostman):
         self.mailer = SMTPAuthenticatedMailer(host, port, user, pw)
 
 
-
 class Postman(SMTPPostman):
     """
     The Postman is your main entrypoint to sending Electronic Mail.
@@ -418,6 +424,7 @@ class GmailPostman(SMTPAuthenticatedPostman):
                                            user=user,
                                            pw=pw)
 
+
 class Letter(object):
     """
     An individual Letter
@@ -443,3 +450,57 @@ class Letter(object):
                 klass.Subject,
                 **klass.Context
                 )
+
+"""
+Testing utilities start here.
+"""
+def _parse_outgoing_mail(sender, to, msgstring):
+    """
+    Parse an outgoing mail and put it into the OUTBOX.
+
+
+    Arguments:
+    - `sender`: str
+    - `to`: str
+    - `msgstring`: str
+
+    Return: None
+    Exceptions: None
+    """
+    global OUTBOX
+    OUTBOX.append(email.message_from_string(msgstring))
+    return
+
+def setup_test_environment():
+    """
+    Set up our environment to test the sending of
+    email with letter.
+
+    We return an outbox for you, into which all emails
+    will be delivered.
+
+    Requires the Mock library.
+
+    Return: list
+    Exceptions: None
+    """
+    import mock
+    global OUTBOX, SMTP
+
+    SMTP = smtplib.SMTP
+    mock_smtp = mock.MagicMock(name='Mock SMTP')
+    mock_smtp.return_value.sendmail.side_effect = _parse_outgoing_mail
+    smtplib.SMTP = mock_smtp
+    return OUTBOX
+
+def teardown_test_environment():
+    """
+    Tear down utilities for the testing of mail sent with letter.
+
+    Return: None
+    Exceptions: None
+    """
+    global OUTBOX, SMTP
+    smtplib.SMTP = SMTP
+    OUTBOX = []
+    return
